==> lalstochastic-1.1.18.tar.xz: lalstochastic-1.1.18/src/LALStochasticVCSInfoHeader.h <==
/*
 * LALStochasticVCSInfo.h - LALStochastic VCS Information Header
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or (at
 * your option) any later version.
 *
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with with program; see the file COPYING. If not, write to the
 * Free Software Foundation, Inc., 59 Temple Place, Suite 330, Boston,
 * MA 02111-1307 USA
 *
 * Copyright (C) 2009-2013 Adam Mercer
 * Copyright (C) 2014 Karl Wette
 */

/** \cond DONT_DOXYGEN */

#ifndef _LALSTOCHASTICVCSINFOHEADER_H
#define _LALSTOCHASTICVCSINFOHEADER_H

#include <lal/LALVCSInfoType.h>
#include <lal/LALStochasticVCSInfo.h>
#include <lal/LALStochasticConfig.h>

#ifdef __cplusplus
extern "C" {
#endif

/* VCS information defines */
#define LALSTOCHASTIC_NAME "LALStochastic"
#define LALSTOCHASTIC_VCS_ID "f13aaac29235dd900d4fa03efc8b0e394c212e84"
#define LALSTOCHASTIC_VCS_DATE "2016-06-26 21:26:32 +0000"
#define LALSTOCHASTIC_VCS_BRANCH "None"
#define LALSTOCHASTIC_VCS_TAG "lalstochastic-v1.1.18"
#define LALSTOCHASTIC_VCS_AUTHOR "Adam Mercer <adam.mercer@ligo.org>"
#define LALSTOCHASTIC_VCS_COMMITTER "Adam Mercer <ramercer@gmail.com>"
#define LALSTOCHASTIC_VCS_STATUS "CLEAN: All modifications committed"

/* Identable VCS information defines */
#define LALSTOCHASTIC_VCS_IDENT_ID "$" "LALStochasticId: f13aaac29235dd900d4fa03efc8b0e394c212e84 " "$"
#define LALSTOCHASTIC_VCS_IDENT_DATE "$" "LALStochasticDate: 2016-06-26 21:26:32 +0000 " "$"
#define LALSTOCHASTIC_VCS_IDENT_BRANCH "$" "LALStochasticBranch: None " "$"
#define LALSTOCHASTIC_VCS_IDENT_TAG "$" "LALStochasticTag: lalstochastic-v1.1.18 " "$"
#define LALSTOCHASTIC_VCS_IDENT_AUTHOR "$" "LALStochasticAuthor: Adam Mercer <adam.mercer@ligo.org> " "$"
#define LALSTOCHASTIC_VCS_IDENT_COMMITTER "$" "LALStochasticCommitter: Adam Mercer <ramercer@gmail.com> " "$"
#define LALSTOCHASTIC_VCS_IDENT_STATUS "$" "LALStochasticStatus: CLEAN: All modifications committed " "$"

/* Header VCS information structure */
static const LALVCSInfo lalStochasticVCSInfoHeader = { \
  LALSTOCHASTIC_NAME, \
  LALSTOCHASTIC_VERSION, \
  LALSTOCHASTIC_VCS_ID, \
  LALSTOCHASTIC_VCS_DATE, \
  LALSTOCHASTIC_VCS_BRANCH, \
  LALSTOCHASTIC_VCS_TAG, \
  LALSTOCHASTIC_VCS_AUTHOR, \
  LALSTOCHASTIC_VCS_COMMITTER, \
  LALSTOCHASTIC_VCS_STATUS \
};

#ifdef __cplusplus
}
#endif

#endif /* _LALSTOCHASTICVCSINFOHEADER_H */

/** \endcond */

/*
 * vim: tw=0 ts=2 et
 */

==> lalstochastic-1.1.19.tar.xz: lalstochastic-1.1.19/src/LALStochasticVCSInfoHeader.h <==
/*
 * LALStochasticVCSInfo.h - LALStochastic VCS Information Header
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or (at
 * your option) any later version.
 *
 * This program is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
 * General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with with program; see the file COPYING. If not, write to the
 * Free Software Foundation, Inc., 59 Temple Place, Suite 330, Boston,
 * MA 02111-1307 USA
 *
 * Copyright (C) 2009-2013 Adam Mercer
 * Copyright (C) 2014 Karl Wette
 */

/** \cond DONT_DOXYGEN */

#ifndef _LALSTOCHASTICVCSINFOHEADER_H
#define _LALSTOCHASTICVCSINFOHEADER_H

#include <lal/LALVCSInfoType.h>
#include <lal/LALStochasticVCSInfo.h>
#include <lal/LALStochasticConfig.h>

#ifdef __cplusplus
extern "C" {
#endif

/* VCS information defines */
#define LALSTOCHASTIC_NAME "LALStochastic"
#define LALSTOCHASTIC_VCS_ID "4fb4d1fc153c792c62434c22228446af38913c75"
#define LALSTOCHASTIC_VCS_DATE "2016-10-10 17:31:35 +0000"
#define LALSTOCHASTIC_VCS_BRANCH "None"
#define LALSTOCHASTIC_VCS_TAG "lalstochastic-v1.1.19"
#define LALSTOCHASTIC_VCS_AUTHOR "Adam Mercer <adam.mercer@ligo.org>"
#define LALSTOCHASTIC_VCS_COMMITTER "Adam Mercer <adam.mercer@ligo.org>"
#define LALSTOCHASTIC_VCS_STATUS "CLEAN: All modifications committed"

/* Identable VCS information defines */
#define LALSTOCHASTIC_VCS_IDENT_ID "$" "LALStochasticId: 4fb4d1fc153c792c62434c22228446af38913c75 " "$"
#define LALSTOCHASTIC_VCS_IDENT_DATE "$" "LALStochasticDate: 2016-10-10 17:31:35 +0000 " "$"
#define LALSTOCHASTIC_VCS_IDENT_BRANCH "$" "LALStochasticBranch: None " "$"
#define LALSTOCHASTIC_VCS_IDENT_TAG "$" "LALStochasticTag: lalstochastic-v1.1.19 " "$"
#define LALSTOCHASTIC_VCS_IDENT_AUTHOR "$" "LALStochasticAuthor: Adam Mercer <adam.mercer@ligo.org> " "$"
#define LALSTOCHASTIC_VCS_IDENT_COMMITTER "$" "LALStochasticCommitter: Adam Mercer <adam.mercer@ligo.org> " "$"
#define LALSTOCHASTIC_VCS_IDENT_STATUS "$" "LALStochasticStatus: CLEAN: All modifications committed " "$"

/* Header VCS information structure */
static const LALVCSInfo lalStochasticVCSInfoHeader = { \
  LALSTOCHASTIC_NAME, \
  LALSTOCHASTIC_VERSION, \
  LALSTOCHASTIC_VCS_ID, \
  LALSTOCHASTIC_VCS_DATE, \
  LALSTOCHASTIC_VCS_BRANCH, \
  LALSTOCHASTIC_VCS_TAG, \
  LALSTOCHASTIC_VCS_AUTHOR, \
  LALSTOCHASTIC_VCS_COMMITTER, \
  LALSTOCHASTIC_VCS_STATUS \
};

#ifdef __cplusplus
}
#endif

#endif /* _LALSTOCHASTICVCSINFOHEADER_H */

/** \endcond */

/*
 * vim: tw=0 ts=2 et
 */
